@@ -4,6 +4,7 @@ from sqlalchemy import (
     Column,
     Integer,
     DateTime,
+    Boolean,
     ForeignKey,
 )
 
@@ -29,6 +30,10 @@ class CompanyLicensingCollabModel(Base):
         ForeignKey('companies_ous.id'),
         nullable=True,
     )
+    target_flag = Column(
+        Boolean,
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
