@@ -6,6 +6,7 @@ from sqlalchemy import (
     Boolean,
     ForeignKey,
     Text,
+    DECIMAL,
 )
 from datetime import datetime
 
@@ -20,6 +21,7 @@ class CompanyOUSModel(Base):
     name = Column(String(190), unique=True, nullable=False)
     ticker = Column(String(20), nullable=True, index=True)
     exchange = Column(String(100), nullable=True)
+    market_cap = Column(DECIMAL(20, 2), nullable=False)
     company_url = Column(String(255), nullable=True)
     pipeline_url = Column(String(255), nullable=True)
     ir_url = Column(String(255), nullable=True)
