@@ -18,6 +18,7 @@ class CompanyOutboxModel(Base):
     cik_str = Column(String(128), nullable=True)
     ticker = Column(String(20), nullable=True)
     name = Column(String(255), nullable=False, index=True)
+    cleaned_name = Column(String(255), nullable=True, index=True)
     exchange = Column(String(50), nullable=True)
     company_sec_id = Column(
         Integer,
@@ -35,6 +36,7 @@ class CompanyOutboxModel(Base):
         ForeignKey('newswires.id'),
         nullable=True,
     )
+    reviewed = Column(Boolean, nullable=True)
     historical = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
