@@ -6,6 +6,7 @@ from sqlalchemy import (
     UniqueConstraint,
     Boolean,
     Text,
+    DECIMAL,
 )
 from datetime import datetime
 
@@ -16,11 +17,12 @@ class CompanySECModel(Base):
     __tablename__ = 'companies_sec'
 
     id = Column(Integer, primary_key=True)
-    lead = Column(Boolean, nullable=True)
+    lead_company = Column(Boolean, nullable=True)
     cik_str = Column(String(128), nullable=False)
     ticker = Column(String(20), nullable=False, index=True)
     title = Column(String(255), nullable=False, index=True)
     exchange = Column(String(50), nullable=True)
+    market_cap = Column(DECIMAL(20, 2), nullable=False)
     company_url = Column(String(255), nullable=True)
     pipeline_url = Column(String(255), nullable=True)
     ir_url = Column(String(255), nullable=True)
