@@ -18,12 +18,13 @@ class CrawlerQueueResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def check_company_ids(self, in_data):
+    def check_company_ids(self, in_data, **kwargs):
         if self._get_number_of_company_fields(in_data) != 1:
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id, not both')
+        return in_data
 
-    def _get_number_of_company_fields(self, in_data):
+    def _get_number_of_company_fields(self, in_data, **kwargs):
         result = 0
         if 'company_sec_id' in in_data:
             if in_data['company_sec_id'] is not None:
@@ -33,7 +34,8 @@ class CrawlerQueueResourceSchema(Schema):
                 result += 1
         return result
 
-    def convert_string_to_datetime(self, in_data):
+    @pre_load
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['entry_date']
 
         in_data = pre_load_date_fields(
