@@ -7,6 +7,7 @@ from sqlalchemy import (
     ForeignKey,
     Text,
     String,
+    Boolean,
 )
 
 from ...database import Base
@@ -28,6 +29,7 @@ class DesignationOutboxModel(Base):
         ForeignKey('newswires.id'),
         nullable=False,
     )
+    processed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
