@@ -36,6 +36,11 @@ class EventModel(Base):
         ForeignKey('newswires.id'),
         nullable=True,
     )
+    sec_filing_id = Column(
+        Integer,
+        ForeignKey('companies_sec_filings.id'),
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
