@@ -5,6 +5,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Text,
+    Boolean,
 )
 from datetime import datetime
 from ...database import Base
@@ -31,6 +32,8 @@ class FDALabelModel(Base):
         nullable=False,
     )
     section_text = Column(Text, nullable=True)
+    is_active = Column(Boolean, nullable=True)
+    vector_active = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
