@@ -7,6 +7,7 @@ from sqlalchemy import (
     ForeignKey,
     String,
     DECIMAL,
+    Boolean,
 )
 
 from ...database import Base
@@ -37,6 +38,7 @@ class IPOModel(Base):
         ForeignKey('newswires.id'),
         nullable=True,
     )
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
