@@ -5,7 +5,6 @@ from marshmallow import (
     pre_load,
     ValidationError,
 )
-from ...utils.utils import pre_load_date_fields
 
 
 class InterventionDataResourceSchema(Schema):
@@ -16,10 +15,9 @@ class InterventionDataResourceSchema(Schema):
     date = fields.DateTime(allow_none=True)
     news_id = fields.Integer(allow_none=True)
     pubmed_id = fields.Integer(allow_none=True)
-    file_id = fields.Integer(allow_none=True)
-    title = fields.String(allow_none=True)
-    orig_file_url = fields.String(allow_none=True)
-    is_deleted = fields.Boolean(allow_none=True)
+    company_filing_id = fields.Integer(allow_none=True)
+    fda_label_id = fields.Integer(allow_none=True)
+    info = fields.String(allow_none=True)
     updated_at = fields.DateTime()
 
     @pre_load
@@ -36,18 +34,10 @@ class InterventionDataResourceSchema(Schema):
         if 'pubmed_id' in in_data:
             if in_data['pubmed_id'] is not None:
                 result += 1
-        if 'file_id' in in_data:
-            if in_data['file_id'] is not None:
+        if 'company_filing_id' in in_data:
+            if in_data['company_filing_id'] is not None:
+                result += 1
+        if 'fda_label_id' in in_data:
+            if in_data['fda_label_id'] is not None:
                 result += 1
         return result
-
-    @pre_load
-    def convert_string_to_datetime(self, in_data, **kwargs):
-        date_fields = ['date']
-
-        in_data = pre_load_date_fields(
-            in_data,
-            date_fields,
-            date_format="%Y%m%dT%H%M%S",
-        )
-        return in_data
