@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
+    Boolean,
 )
 
 from ...database import Base
@@ -23,6 +24,7 @@ class InterventionDataStageModel(Base):
         Integer,
         nullable=False,
     )
+    preferred = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
