@@ -7,6 +7,7 @@ from sqlalchemy import (
     UniqueConstraint,
     ForeignKey,
     Boolean,
+    Float,
 )
 
 from ...database import Base
@@ -26,6 +27,10 @@ class InterventionSalesModel(Base):
         ForeignKey('sales.id'),
         nullable=False,
     )
+    score = Column(
+        Float,
+        nullable=False,
+    )
     is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
