@@ -5,7 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     ForeignKey,
-    Text,
+    Boolean,
 )
 
 from ...database import Base
@@ -21,6 +21,7 @@ class LicensingCollabModel(Base):
         ForeignKey('newswires.id'),
         nullable=False,
     )
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
