@@ -33,8 +33,8 @@ class NCTChangeModel(Base):
         ForeignKey('pubmed.id'),
         nullable=True,
     )
-    old_value = Column(String(256), nullable=True)
-    new_value = Column(String(256), nullable=True)
+    old_value = Column(Text, nullable=True)
+    new_value = Column(Text, nullable=True)
     note = Column(Text, nullable=True)
     updated_at = Column(
         DateTime,
