@@ -14,6 +14,7 @@ class NCTStudyResourceSchema(Schema):
     nct_id = fields.String(allow_none=False)
     acronym = fields.String(allow_none=True)
     brief_title = fields.String(allow_none=True)
+    official_title = fields.String(allow_none=True)
     brief_summary = fields.String(allow_none=True)
     description = fields.String(allow_none=True)
     enrollment = fields.Integer(allow_none=True)
@@ -33,6 +34,7 @@ class NCTStudyResourceSchema(Schema):
     conditions = fields.String(allow_none=True)
     interventions = fields.String(allow_none=True)
     industry_flag = fields.Boolean()
+    study_keywords = fields.String(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
