@@ -5,6 +5,7 @@ from sqlalchemy import (
     Text,
     DateTime,
     ForeignKey,
+    Boolean,
 )
 from datetime import datetime
 
@@ -26,6 +27,7 @@ class NewswireModel(Base):
     filtered_conditions = Column(Text)
     news_file_id = Column(Integer, ForeignKey("files.id"))
     source_link = Column(Text, nullable=True)
+    is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
