@@ -2,6 +2,8 @@ from sqlalchemy import (
     Column,
     Integer,
     DateTime,
+    String,
+    Boolean,
 )
 from datetime import datetime
 
@@ -17,6 +19,12 @@ class NewswireFinancingOutboxModel(Base):
         nullable=False,
         index=True,
     )
+    source = Column(
+        String(20),
+        nullable=False,
+    )
+    submitted = Column(Boolean, nullable=True)
+    historical = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
