@@ -3,6 +3,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     String,
+    Boolean,
 )
 from datetime import datetime
 
@@ -19,6 +20,8 @@ class NewswireIPOOutboxModel(Base):
         index=True,
     )
     type = Column(String(50), nullable=True)
+    submitted = Column(Boolean, nullable=True)
+    historical = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
