@@ -31,6 +31,8 @@ class NewswireTableModel(Base):
     )
     table_hash = Column(String(64), nullable=True)
     is_deleted = Column(Boolean, nullable=True)
+    table_class = Column(String(50), nullable=True)
+    reviewed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
