@@ -15,4 +15,6 @@ class NewswireTableResourceSchema(Schema):
     table_html_file_id = fields.Integer(allow_none=True)
     table_hash = fields.String(allow_none=True)
     is_deleted = fields.Boolean(allow_none=True)
+    table_class = fields.String(allow_none=True)
+    reviewed = fields.String(allow_none=True)
     updated_at = fields.DateTime()
