@@ -1,7 +1,7 @@
 from sqlalchemy.exc import SQLAlchemyError
 from sqlalchemy.sql.operators import in_op
 from datetime import datetime
-from marshmallow import ValidationError
+from marshmallow import ValidationError, EXCLUDE
 
 from ...database import db_session
 from ...utils.utils import update_model
@@ -59,12 +59,11 @@ class OrangeBookPatent:
             ValidationError
         """
 
-        data, errors = schema_params.load(params)
-        if errors:
-            raise ValidationError(errors)
+        data = schema_params.load(params, unknown=EXCLUDE)
+
         orange_book_patent_query = _build_query(params=data)
         response = schema_resource.dump(
-            orange_book_patent_query, many=True).data
+            orange_book_patent_query, many=True)
         return response
 
     @staticmethod
@@ -78,11 +77,10 @@ class OrangeBookPatent:
             ValidationError
         """
 
-        data, errors = schema_params.load(params)
-        if errors:
-            raise ValidationError(errors)
+        data = schema_params.load(params, unknown=EXCLUDE)
+
         orange_book_patent_query = _build_query(params=data).one()
-        response = schema_resource.dump(orange_book_patent_query).data
+        response = schema_resource.dump(orange_book_patent_query)
         return response
 
     @staticmethod
@@ -124,7 +122,7 @@ def _helper_create(data):
             OrangeBookPatentModel).get(
             new_orange_book_patent.id,
         )
-        response = schema_resource.dump(orange_book_patent_query).data
+        response = schema_resource.dump(orange_book_patent_query)
         db_session.close()
         return response
     except SQLAlchemyError:
@@ -139,7 +137,7 @@ def _helper_update(data, orange_book_patent_query):
     try:
         update_model(data, orange_book_patent_query)
         db_session.commit()
-        response = schema_resource.dump(orange_book_patent_query).data
+        response = schema_resource.dump(orange_book_patent_query)
         return response
     except SQLAlchemyError:
         db_session.rollback()
