@@ -68,7 +68,7 @@ class PTAB2DocumentResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         return _pre_load_datetime_fields(in_data)
 
 
