@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     Text,
     DateTime,
+    Boolean,
     UniqueConstraint,
 )
 from datetime import datetime
@@ -30,6 +31,8 @@ class PatentApplicationModel(Base):
     title = Column(String(500))
     docdb_family_id = Column(Integer, nullable=True)
     inpadoc_family_id = Column(Integer, nullable=True)
+    is_orange_book = Column(Boolean, nullable=True)
+    is_purple_book = Column(Boolean, nullable=True)
 
     updated_at = Column(
         DateTime,
