@@ -31,7 +31,7 @@ class PatentApplicationTargetModel(Base):
         nullable=False,
     )
     preferred = Column(Boolean, nullable=True)
-    filed_date = Column(DateTime, nullable=True)
+    published_date = Column(DateTime, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
