@@ -11,7 +11,7 @@ class PromptIndicesSchema(Schema):
     id = fields.Integer(dump_only=True)
     prompt_index = fields.String(required=True)
     text = fields.String(required=True)
-    metadata = fields.String(required=True)
+    metadatas = fields.String(required=True)
     vector = fields.String(required=True)
     search_type = fields.String(allow_none=True)
     updated_at = fields.DateTime()
