@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     String,
+    Boolean,
     ForeignKey,
 )
 
@@ -21,6 +22,8 @@ class PubmedPMCModel(Base):
         nullable=False,
     )
     pmc_id = Column(String(20), nullable=False)
+    processed = Column(Boolean, nullable=True)
+    found = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
