@@ -27,6 +27,8 @@ class SalesModel(Base):
     )
     table_number = Column(Integer, nullable=False)
     table_preceding_info = Column(Text, nullable=True)
+    table_html = Column(Text, nullable=True)
+    table_info = Column(Text, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
@@ -34,4 +36,3 @@ class SalesModel(Base):
         default=lambda: datetime.utcnow(),
         onupdate=lambda: datetime.utcnow(),
     )
-
