@@ -13,4 +13,6 @@ class SalesResourceSchema(Schema):
     table_html_file_id = fields.Integer(allow_none=True)
     table_number = fields.Integer(required=True)
     table_preceding_info = fields.String(allow_none=True)
+    table_html = fields.String(allow_none=True)
+    table_info = fields.String(allow_none=True)
     updated_at = fields.DateTime()
