@@ -17,7 +17,7 @@ class SubsidiaryResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def pre_load(self, in_data, **kwargs):
+    def check_company_ids(self, in_data, **kwargs):
         if self._get_number_of_company_fields(in_data) > 1:
             raise ValidationError('Provide either company_sec_id or '
                                   'company_ous_id, not both')
