@@ -3,6 +3,8 @@ from datetime import datetime
 from sqlalchemy import (
     Column,
     Integer,
+    Float,
+    Boolean,
     DateTime,
     Text,
 )
@@ -18,6 +20,8 @@ class TableOutboxModel(Base):
     table_html = Column(Text, nullable=False)
     table_number = Column(Integer, nullable=False)
     table_preceding_info = Column(Text, nullable=False)
+    score = Column(Float, nullable=True)
+    processed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
