@@ -13,4 +13,6 @@ class TableOutboxResourceSchema(Schema):
     table_number = fields.Integer(required=True)
     table_html = fields.String(required=True)
     table_preceding_info = fields.String(required=True)
+    score = fields.Float(allow_none=True)
+    processed = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
